[pLog-svn] r6424 - plugins/branches/lifetype-1.2/bin

jondaley at devel.lifetype.net jondaley at devel.lifetype.net
Thu May 1 14:47:48 EDT 2008


Author: jondaley
Date: 2008-05-01 14:47:48 -0400 (Thu, 01 May 2008)
New Revision: 6424

Modified:
   plugins/branches/lifetype-1.2/bin/build.sh
Log:
copied changes from template build script to plugin build script, and standardized parameter order.  removed old stuff

Modified: plugins/branches/lifetype-1.2/bin/build.sh
===================================================================
--- plugins/branches/lifetype-1.2/bin/build.sh	2008-05-01 18:19:55 UTC (rev 6423)
+++ plugins/branches/lifetype-1.2/bin/build.sh	2008-05-01 18:47:48 UTC (rev 6424)
@@ -1,29 +1,11 @@
 #!/bin/sh
 
 #
-# Script to generate distribution builds of pLog
+# Script to generate distribution builds of LifeType
 #
-# (c) 27-08-2004, the pLog Team
-#
-#
-# Requires two parameters: the name of the output package and the
-# CVS tag label that will be used to fetch the contents of the build. Therefore,
-# contents must be tagged _before_ running this script. 
-# The same CVS label must be used for both the plog_devel and plog_docs module.
-#
+# (c) 27-08-2004, the LifeType Team
 
 #
-# server and repository path
-#
-SVNSERVER=http://devel.lifetype.net
-SVNREPO=/svn/plog/plugins/branches/lifetype-1.2
-
-#
-# save the current folder
-#
-CWD=`pwd`
-
-#
 # array with the files that we are going to remove before
 # making the package... Wildcards, complete paths, whatever
 # can be used here
@@ -58,19 +40,23 @@
 if [ $# -lt 1 ]; then
     echo "Makes a zip package of a given plugin"
     echo ""
-	echo "Usage: build.sh template"
+	echo "Usage: build.sh [noupload] <plugin name>"
 	echo ""
-	echo "Use 'all' in order to generate a package of all the template sets"
+	echo "Use 'all' in order to generate a package of all the plugins"
 	exit -1
 fi
 
-# get the name of the template that we're trying to build
-TEMPLATENAME=$1
+# get the name of the plugin that we're trying to build
+if [ "${1:-}" == "noupload" ]; then
+  message "Building, not uploading";
+  UPLOAD=0
+  TEMPLATENAME=$2
+else
+  message "Building and uploading";
+  UPLOAD=1
+  TEMPLATENAME=$1
+fi
 
-# set second parameter to anything if you don't want the files to
-# be automatically uploaded
-DONT_UPLOAD=$2
-
 # a temporary working folder like any other...
 TMPFOLDER=${WORKFOLDER}`date | md5`
 CURFOLDER=`pwd`
@@ -120,7 +106,7 @@
 	zip -r ${CURFOLDER}/${VERSION}_${TEMPLATENAME}.zip $FILES
 fi
 
-if [ "x$DONT_UPLOAD" == "x" ]; then
+if [ "$UPLOAD" == "1" ]; then
   # upload the package.  Linux ftp (at least my version,
   # doesn't have the -a command,
   # but I can use curl to do the same thing.



More information about the pLog-svn mailing list